@@ -32,7 +32,7 @@ eval 'use Net::OpenSSH; use IO::Pty; $haveit{"openssh"} = 1; 1';
 eval 'use Net::FSP; $haveit{"fsp"} = 1; 1';
 eval 'use Net::FTPSSL; $haveit{"ftpssl"} = 1; 1';
 
-our $VERSION = '0.50';
+our $VERSION = '0.51';
 
 sub new
 {
@@ -669,6 +669,13 @@ Returns 1 if Net::SFTP is installed, 0 otherwise.
 Returns a reference to a hash in the form: 
 { 'Net::FTP' => 1|0, 'Net::SFTP' => 1|0 }
 
+=item Net::xFTP->haveModule ( MODULE_NAME )
+
+Expects the name of one of the supported FTP modules (currently:  'Net::FTP', 'Net::SFTP', 'Net::SSH2',
+'Net::SFTP::Foreign', 'Net::OpenSSH', 'Net::FSP', or 'Net::FTPSSL'.
+
+Returns either 1, if the module is installed or 0 if not.
+
 =item new ( PROTOCOL, HOST [, OPTIONS ])
 
 This is the constructor.  It returns either a Net::xFTP object or I<undef> 
