@@ -472,7 +472,8 @@ sub isadir
 	if (defined($ok) && $ok)
 	{
 		eval { $self->{xftp}->closedir($ok) };
-		return 1;
+		my $stat = $self->{xftp}->stat($path);   #JWT:NEXT 2 ADDED PATCH BY mavit.org.uk TO ADDRESS BUG#74082: Net::xFTP::Foreign::isadir() to GlobalSCAPE EFT
+		return 1  if (defined($stat) && S_ISDIR($stat->perm));
 	}
 	return 0;
 }
